[llvm-commits] CVS: llvm/tools/llvm-ld/llvm-ld.cpp

Reid Spencer reid at x10sys.com
Tue Apr 3 23:34:39 PDT 2007



Changes in directory llvm/tools/llvm-ld:

llvm-ld.cpp updated: 1.49 -> 1.50
---
Log message:

For PR1302: http://llvm.org/PR1302 :
Rename LinkItems as NativeLinkItems since it is filled out by the Linker
library to contain only those items deemed to be native.


---
Diffs of the changes:  (+13 -12)

 llvm-ld.cpp |   25 +++++++++++++------------
 1 files changed, 13 insertions(+), 12 deletions(-)


Index: llvm/tools/llvm-ld/llvm-ld.cpp
diff -u llvm/tools/llvm-ld/llvm-ld.cpp:1.49 llvm/tools/llvm-ld/llvm-ld.cpp:1.50
--- llvm/tools/llvm-ld/llvm-ld.cpp:1.49	Fri Feb 16 13:11:07 2007
+++ llvm/tools/llvm-ld/llvm-ld.cpp	Wed Apr  4 01:34:22 2007
@@ -268,12 +268,12 @@
 /// specified bytecode file.
 ///
 /// Inputs:
 ///  InputFilename  - The name of the input bytecode file.
 ///  OutputFilename - The name of the file to generate.
 ///  LinkItems      - The native libraries, files, code with which to link
 ///  LibPaths       - The list of directories in which to find libraries.
 ///  gcc            - The pathname to use for GGC.
 ///  envp           - A copy of the process's current environment.
 ///
 /// Outputs:
 ///  None.
@@ -446,8 +446,9 @@
 
     // Construct a Linker (now that Verbose is set)
     Linker TheLinker(progname, OutputFilename, Verbose);
-    // Keep track of the native link items (vice the bytecode items)
-    Linker::ItemList LinkItems;
+
+    // Keep track of the native link items (versus the bytecode items)
+    Linker::ItemList NativeLinkItems;
 
     // Add library paths to the linker
     TheLinker.addPaths(LibPaths);
@@ -476,7 +477,7 @@
       BuildLinkItems(Items, InputFilenames, Libraries);
 
       // Link all the items together
-      if (TheLinker.LinkInItems(Items,LinkItems) )
+      if (TheLinker.LinkInItems(Items, NativeLinkItems) )
         return 1; // Error already printed
     }
 
@@ -563,7 +564,7 @@
         if (Verbose) 
           cout << "Generating Native Code\n";
         if (0 != GenerateNative(OutputFilename, AssemblyFile.toString(),
-            LinkItems,gcc,envp,ErrMsg))
+                                NativeLinkItems, gcc, envp, ErrMsg))
           PrintAndExit(ErrMsg);
 
         // Remove the assembly language file.
@@ -595,8 +596,8 @@
 
         if (Verbose) 
           cout << "Generating Native Code\n";
-        if (0 != GenerateNative(OutputFilename, CFile.toString(), LinkItems, 
-            gcc, envp, ErrMsg))
+        if (0 != GenerateNative(OutputFilename, CFile.toString(), 
+                                NativeLinkItems, gcc, envp, ErrMsg))
           PrintAndExit(ErrMsg);
 
         // Remove the assembly language file.
@@ -268,12 +268,12 @@
 ///
 /// Inputs:
-///  InputFilename  - The name of the input bytecode file.
-///  OutputFilename - The name of the file to generate.
-///  LinkItems      - The native libraries, files, code with which to link
-///  LibPaths       - The list of directories in which to find libraries.
-///  gcc            - The pathname to use for GGC.
-///  envp           - A copy of the process's current environment.
+///  InputFilename   - The name of the input bytecode file.
+///  OutputFilename  - The name of the file to generate.
+///  NativeLinkItems - The native libraries, files, code with which to link
+///  LibPaths        - The list of directories in which to find libraries.
+///  gcc             - The pathname to use for GGC.
+///  envp            - A copy of the process's current environment.
 ///
 /// Outputs:






More information about the llvm-commits mailing list